[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] [xen-unstable] x86: Rename __sync_lazy_execstate() to __sync_local_execstate().



# HG changeset patch
# User Keir Fraser <keir.fraser@xxxxxxxxxx>
# Date 1271696248 -3600
# Node ID fadf63ab49e736adad49116672d168c321c8e060
# Parent  db149766aef1958dab27932950a53eec7c06ca6a
x86: Rename __sync_lazy_execstate() to __sync_local_execstate().

This naming scheme is more rational. Also use non-x86-specific
function sync_local_execstate() where possible.

Signed-off-by: Keir Fraser <keir.fraser@xxxxxxxxxx>
---
 xen/arch/x86/domain.c             |   12 ++++++------
 xen/arch/x86/smp.c                |    2 +-
 xen/arch/x86/smpboot.c            |    4 ++--
 xen/arch/x86/x86_32/domain_page.c |    2 +-
 xen/include/asm-x86/mm.h          |    2 +-
 5 files changed, 11 insertions(+), 11 deletions(-)

diff -r db149766aef1 -r fadf63ab49e7 xen/arch/x86/smp.c
--- a/xen/arch/x86/smp.c        Mon Apr 19 17:53:10 2010 +0100
+++ b/xen/arch/x86/smp.c        Mon Apr 19 17:57:28 2010 +0100
@@ -211,7 +211,7 @@ fastcall void smp_invalidate_interrupt(v
     ack_APIC_irq();
     perfc_incr(ipis);
     irq_enter();
-    if ( !__sync_lazy_execstate() ||
+    if ( !__sync_local_execstate() ||
          (flush_flags & (FLUSH_TLB_GLOBAL | FLUSH_CACHE)) )
         flush_area_local(flush_va, flush_flags);
     cpu_clear(smp_processor_id(), flush_cpumask);
diff -r db149766aef1 -r fadf63ab49e7 xen/arch/x86/smpboot.c
--- a/xen/arch/x86/smpboot.c    Mon Apr 19 17:53:10 2010 +0100
+++ b/xen/arch/x86/smpboot.c    Mon Apr 19 17:57:28 2010 +0100
@@ -1003,7 +1003,7 @@ void cpu_exit_clear(void)
        int cpu = raw_smp_processor_id();
 
        /* Previous non-idle state should be synchronised already. */
-       if (__sync_lazy_execstate())
+       if (__sync_local_execstate())
                BUG();
 
        cpucount --;
@@ -1304,7 +1304,7 @@ int __cpu_disable(void)
         * before changing cpu_online_map. If we are running non-idle vcpu,
         * we will synchronously sync the state in context_switch() later.
         */
-       __sync_lazy_execstate();
+       sync_local_execstate();
 
        /* It's now safe to remove this processor from the online map */
        cpu_clear(cpu, cpu_online_map);
diff -r db149766aef1 -r fadf63ab49e7 xen/arch/x86/x86_32/domain_page.c
--- a/xen/arch/x86/x86_32/domain_page.c Mon Apr 19 17:53:10 2010 +0100
+++ b/xen/arch/x86/x86_32/domain_page.c Mon Apr 19 17:57:28 2010 +0100
@@ -32,7 +32,7 @@ static inline struct vcpu *mapcache_curr
     {
         /* If we really are idling, perform lazy context switch now. */
         if ( (v = idle_vcpu[smp_processor_id()]) == current )
-            __sync_lazy_execstate();
+            sync_local_execstate();
         /* We must now be running on the idle page table. */
         ASSERT(read_cr3() == __pa(idle_pg_table));
     }
diff -r db149766aef1 -r fadf63ab49e7 xen/include/asm-x86/mm.h
--- a/xen/include/asm-x86/mm.h  Mon Apr 19 17:53:10 2010 +0100
+++ b/xen/include/asm-x86/mm.h  Mon Apr 19 17:57:28 2010 +0100
@@ -532,7 +532,7 @@ void propagate_page_fault(unsigned long 
 void propagate_page_fault(unsigned long addr, u16 error_code);
 void *do_page_walk(struct vcpu *v, unsigned long addr);
 
-int __sync_lazy_execstate(void);
+int __sync_local_execstate(void);
 
 /* Arch-specific portion of memory_op hypercall. */
 long arch_memory_op(int op, XEN_GUEST_HANDLE(void) arg);

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.
diff -r db149766aef1 -r fadf63ab49e7 xen/arch/x86/domain.c
--- a/xen/arch/x86/domain.c     Mon Apr 19 17:53:10 2010 +0100
+++ b/xen/arch/x86/domain.c     Mon Apr 19 17:57:28 2010 +0100
@@ -1429,7 +1429,7 @@ void context_switch(struct vcpu *prev, s
     ASSERT(cpus_weight(dirty_mask) <= 1);
     if ( unlikely(!cpu_isset(cpu, dirty_mask) && !cpus_empty(dirty_mask)) )
     {
         /* Other cpus call __sync_lazy_execstate from flush ipi handler. */
         flush_tlb_mask(&dirty_mask);
     }
 
@@ -1489,7 +1489,7 @@ void continue_running(struct vcpu *same)
     BUG();
 }
 
-int __sync_lazy_execstate(void)
+int __sync_local_execstate(void)
 {
     unsigned long flags;
     int switch_required;
@@ -1511,15 +1511,15 @@ int __sync_lazy_execstate(void)
 
 void sync_local_execstate(void)
 {
-    (void)__sync_lazy_execstate();
+    (void)__sync_local_execstate();
 }
 
 void sync_vcpu_execstate(struct vcpu *v)
 {
     if ( cpu_isset(smp_processor_id(), v->vcpu_dirty_cpumask) )
-        (void)__sync_lazy_execstate();
-
-    /* Other cpus call __sync_lazy_execstate from flush ipi handler. */
+        sync_local_execstate();
+
+    /* Other cpus call __sync_local_execstate from flush ipi handler. */
     flush_tlb_mask(&v->vcpu_dirty_cpumask);
 }
 
@@ -1429,7 +1429,7 @@ void context_switch(struct vcpu *prev, s
     if ( unlikely(!cpu_isset(cpu, dirty_mask) && !cpus_empty(dirty_mask)) )
     {
-        /* Other cpus call __sync_lazy_execstate from flush ipi handler. */
+        /* Other cpus call __sync_local_execstate from flush ipi handler. */
         flush_tlb_mask(&dirty_mask);
     }